#
# spec file for package netatalk
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define with_afpstats  0
%define with_tracker_spotlight 0
%define libmaj  16
Name:           netatalk
Version:        3.1.7
Release:        8.3.1
Summary:        AFP Fileserver for Macintosh Clients
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
Url:            http://netatalk.sourceforge.net/
Source:         http://downloads.sourceforge.net/project/netatalk/netatalk/%{version}/netatalk-%{version}.tar.bz2
Source1:        netatalk-latinize.pl
Source3:        netatalk-upgrade_netatalk_AppleDB.sh
Source4:        netatalk-rpmlintrc
# see bnc#849598 and http://sourceforge.net/p/netatalk/bugs/538/
Patch0:         %{name}-wrong-error-message.patch
Patch2:         netatalk-libc-xattr.patch
Patch3:         fce-afpd-fix-fce_event_names-array-overflow.patch
Patch4:         netatalk-CVE-2018-1160.patch
BuildRequires:  automake
BuildRequires:  db-devel
BuildRequires:  fdupes
BuildRequires:  krb5-devel
BuildRequires:  libacl-devel
BuildRequires:  libavahi-devel
BuildRequires:  libevent-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libtdb-devel
BuildRequires:  libtool
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  pkg-config
BuildRequires:  tcpd-devel
BuildRequires:  zlib-devel
Requires:       cyrus-sasl
Requires:       db-utils
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         %insserv_prereq %fillup_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?with_afpstats}%{?with_tracker_spotlight}
BuildRequires:  dbus-1-devel
BuildRequires:  dbus-1-glib-devel
%if 0%{?with_tracker_spotlight}
BuildRequires:  tracker-devel
%endif
%endif
%if 0%{?suse_version} > 1210
BuildRequires:  systemd
%{?systemd_requires}
%endif

%description
Netatalk is a freely-available Open Source AFP fileserver. A *NIX/*BSD
system running Netatalk is capable of serving many Macintosh clients
simultaneously as an AppleShare file server (AFP).

%package -n libatalk%{libmaj}
Summary:        Netatalk AFP Fileserver for Macintosh Clients
Group:          Development/Libraries/C and C++

%description -n libatalk%{libmaj}
Netatalk is a freely-available Open Source AFP fileserver. A *NIX/*BSD
system running Netatalk is capable of serving many Macintosh clients
simultaneously as an AppleShare file server (AFP).

%package devel
Summary:        Netatalk AFP Fileserver for Macintosh Clients
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       glibc-devel

%description devel
Netatalk is a freely-available Open Source AFP fileserver. A *NIX/*BSD
system running Netatalk is capable of serving many Macintosh clients
simultaneously as an AppleShare file server (AFP).

%prep
%setup -q -n netatalk-%{version}
%patch0
%patch2 -p1
%patch3 -p1
%patch4 -p1
cp -avL %{SOURCE1} .

%build
autoreconf -fiv
LDFLAGS="-lpthread" \
CFLAGS="%{optflags} -Wall -g -pie -fpie" \
%if 0%{?with_tracker_spotlight}
tracker_ver=$(rpm -q --queryformat="%{VERSION}" tracker-devel|cut -d . -f 1-2)
%endif
%configure --bindir=%{_bindir} \
        --disable-silent-rules \
	--disable-static \
	--with-pic \
	--with-shadow \
	--with-pam \
	--with-ldap \
        --with-acls \
	--enable-pgp-uam \
        --enable-krbV-uam \
	--enable-overwrite \
	--enable-quota \
	--with-libevent=no \
	--with-tdb=no \
	--libexecdir=%{_libdir}/netatalk \
        --localstatedir=%{_localstatedir}/lib \
        --with-pkgconfdir=%{_sysconfdir}/netatalk \
%if %{with_afpstats} == 1
        --with-afpstats \
%endif
%if 0%{?with_tracker_spotlight}
	--with-tracker-pkgconfig-version=${tracker_ver} \
%endif
        --with-init-style=suse-systemd
make %{?_smp_mflags}
mkdir examples
cp netatalk-latinize.pl examples
sed -i '/\/var\/lock\/subsys/d' distrib/initscripts/rc.suse

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%if 0%{?suse_version} > 1140
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%else
mkdir -p %{buildroot}%{_sysconfdir}/init.d/
install -m 755 distrib/initscripts/rc.suse %{buildroot}%{_sysconfdir}/init.d/netatalk
ln -sf ../..%{_initddir}/netatalk %{buildroot}%{_sbindir}/rc%{name}
%endif
install -m 755 %{SOURCE3} %{buildroot}%{_sbindir}/upgrade_netatalk_AppleDB.sh
#
# Conflicts with yudit
rm %{buildroot}%{_mandir}/man1/uniconv.1*
#
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes -s %{buildroot}%{_mandir}

%pre
test -f etc/atalk/afpd.conf && {
echo
echo "netatalk config files have been moved to %{_sysconfdir}/afp.conf"
echo "a backup can be found in %{_sysconfdir}/atalk"
echo "please compare them before restarting the netatalk server"
}
test -f etc/netatalk/afpd.conf && {
echo
echo "netatalk config files have been moved to %{_sysconfdir}/afp.conf"
echo "a backup can be found in %{_sysconfdir}/netatalk"
echo "please compare them before restarting the netatalk server"
}
%if 0%{?suse_version} > 1210
%service_add_pre netatalk.service
%endif
exit 0

%preun
%stop_on_removal netatalk
%if 0%{?suse_version} > 1210
%service_del_preun netatalk.service
%endif

%post
%restart_on_update netatalk
%if 0%{?suse_version} > 1210
%service_add_post netatalk.service
%{fillup_only netatalk}
%else
%{fillup_and_insserv netatalk}
%endif

%postun
%if 0%{?suse_version} > 1210
%service_del_postun netatalk.service
%else
%insserv_cleanup
%endif

%post -n libatalk%{libmaj} -p /sbin/ldconfig

%postun -n libatalk%{libmaj} -p /sbin/ldconfig

%files
%defattr (-,root,root)
%attr(755,root,root) %{_bindir}/*
%attr(755,root,root) %{_sbindir}/*
%dir %{_libdir}/netatalk
%{_libdir}/netatalk/*
%{_mandir}/man?/*
%doc AUTHORS CONTRIBUTORS COPYING COPYRIGHT NEWS VERSION examples
#
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/afp.conf
%config(noreplace) %{_sysconfdir}/%{name}/extmap.conf
%config(noreplace) %{_sysconfdir}/%{name}/dbus-session.conf
%if 0%{?with_afpstats}%{?with_tracker_spotlight}
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/netatalk-dbus.conf
%endif
%dir %{_sysconfdir}/pam.d
%config %{_sysconfdir}/pam.d/*
#
%if 0%{?suse_version} > 1210
%{_libexecdir}/systemd/system/netatalk.service
%else
%attr(755,root,root) %{_sysconfdir}/init.d/netatalk
%endif
%{_localstatedir}/lib/%{name}

%files -n libatalk%{libmaj}
%defattr (-,root,root)
%{_libdir}/libatalk.so.*
%doc COPYING COPYRIGHT

%files devel
%defattr (-,root,root)
%dir %{_datadir}/aclocal
%dir %{_includedir}/atalk
%{_libdir}/libatalk.so
%{_datadir}/aclocal/*
%{_includedir}/atalk/*

%changelog
* Tue Dec 18 2018 Petr Gajdos <pgajdos@suse.com>
- security update
  * CVE-2018-1160 [bsc#1119540]
    + netatalk-CVE-2018-1160.patch
* Tue Jan 20 2015 mpluskal@suse.com
- Don't install init script on systems with systemd
- Spec file cleanup with spec-cleaner
- Fix systemd specific conditions to match packaging guidelines
* Sun Jan 11 2015 jeffm@suse.com
- fce: afpd: fix fce_event_names array overflow
  * Added: fce-afpd-fix-fce_event_names-array-overflow.patch
* Wed Jan  7 2015 jeffm@suse.com
- update to 3.1.7:
  * UPD: Spotlight: enhance behaviour for long running queries, client
    will now show "progress wheel" while waiting for first results.
  * FIX: netatalk: fix a crash on Solaris when registering with mDNS
  * FIX: netatalk: SIGHUP would kill the process instead of being
    resent to the other Netatalk processes, bug #579
  * FIX: afpd: Solaris locking problem, bug #559
  * FIX: Handling of malformed UTF8 strings, bug #524
  * FIX: afpd: umask handling, bug #576
  * FIX: Spotlight: Limiting searches to subfolders, bug #581
  * FIX: afpd: reloading logging config may result in privilege
    escalation in afpd processes
  * FIX: afpd: ACL related error messages, now logged with loglevel
    debug instead of error
  * FIX: cnid_metad: fix tsockfd_create() return value on error
  * FIX: CNID/MySQL: volume table name generation, bug #566.
  - via 3.0.6:
  * FIX: charset conversion failed when copying from Mac OS 9. Bug #523.
  * UPD: Don’t force S_ISGID for directories on FreeBSD. Bug #525.
  * NEW: Add support for ZFS ACLs on FreeBSD with libsunacl. From FR#83.
  * FIX: Active Directory LDAP queries for ACL support with new options
    "ldap user filter" and "ldap group filter". Bug #526.
  * NEW: Option "vol dbnest", when set to true, the CNID database for a
    volume is stored in the volume root of a share in a directory
    .AppleDB like in Netatalk 2. Defaults to false. From FR#84.
  * FIX: Small fix in the DSI tickle handling. Bug #528.
  * UPD: Enhance handling of connection attempts when hitting the
    connection limit. Bug #529.
  * FIX: Saving from Word to a folder that is a symlink to a folder on
    another filesystem results in a crash of the afpd process and the save
    to fail. This happens only if the option "follow symlinks" is enabled.
    Bug #532.
  * FIX: Disable Kerberos UAM if AFP service principal name can’t be
    evaluated. Fixes bug #531.
  * FIX: Fix handling of large number of volumes. Bug #527.
  * NEW: Configure option --with-tbd which can be used to disable the use
    of the bundled tdb and use a system installed version.
- Added build support for spotlight tracker but it is disabled due to
  dbus security policy.
* Tue Nov 18 2014 pgajdos@suse.com
- update to 3.1.6:
  * FIX: Spotlight: fix for long running queries
  * UPD: afpd: distribute SIGHUP from parent afpd to children and force
    reload shares
  * FIX: netatalk: refresh Zeroconf registration when receiving SIGHUP
  * NEW: configure option "--with-init-style=debian-systemd" for Debian
    8 jessieand later.
  * FIX: afpd: Hangs in Netatalk which causes it to stop responding to
    connections, bug #572.
  * NEW: afpd: new option "force xattr with sticky bit = yes|no"
    (default: no), FR #94
  * UPD: afpd: FCE version 2 with new event types and new config options
    "fce ignore names" and "fce notify script"
  * UPD: afpd: check for modified included config file, FR #95.
  * UPD: libatalk: logger: remove flood protection and allocate messages
  * UPD: Spotlight: use async Tracker SPARQL API
  * NEW: afpd: new option "case sensitive = yes|no" (default: yes)
    In spite of being case sensitive as a matter of fact, netatalk
    3.1.3 and earlier did not notify kCaseSensitive flag to the client.
    Now, it is notified correctly by default, FR #62.
  * UPD: Spotlight: more SPARQL query optimisations
  * UPD: Spotlight: new options "sparql results limit", "spotlight
    attributes" and "spotlight expr"
  * FIX: afpd: Unarchiving certain ZIP archives fails, bug #569
  * UPD: Update Unicode support to version 7.0.0
  * FIX: Memory overflow caused by 'basedir regex', bug #567
  * NEW: afpd: delete empty resource forks, from FR #92
  * FIX: afpd: fix a crash when accessing ._ AppleDouble files created
    by OS X via SMB, bug #564
  * FIX: afpd and dbd: Converting from AppleDouble v2 to ea may corrupt
    the resource fork. In some circumstances an offset calculation
    is wrong resulting in corrupt resource forks after the
    conversion. Bug #568.
  * FIX: ad: fix for bug #563 broke ad file utilities, bug #570.
  * NEW: afpd: new advanced option controlling permissions and ACLs,
    from FR #93
- removed upstreamed netatalk-return-code.patch
* Fri Jun 20 2014 pgajdos@suse.com
- update to 3.1.2:
  * FIX: Option "vol dbpath" was broken in 3.1.1
  * FIX: Spotlight: file modification date, bug #545
  * FIX: Improve reliability of afpd child handler
  * FIX: debian initscript: add 0 and 6 to Default-Stop. debian-bug#745520
  * FIX: put the Solaris share reservation after our locking stuff, bug #560.
  * UPD: Improve Linux quota behaviour
  * FIX: xattrs on *BSD, bug #562
  * NEW: afpd: support for using $u username variable in AFP volume
    definitions. FR#90.
  * FIX: getvolbypath returns incorrect volume, bug #563
  * FIX: fd leak when using appledouble = v2, bug #554
  * UPD: New options that control whether dbus and Tracker are started:
    'start dbus' and 'start tracker', both default to yes, FR#91
  * UPD: Spotlight: SPARQL query optimisations
* Fri Jun  6 2014 crrodriguez@opensuse.org
- netatalk-libc-xattr.patch Do not depend on libattr, glibc
  provides the "official" xattr syscalls interface.
* Fri Jun  6 2014 crrodriguez@opensuse.org
- Use the system's libtdb, not the bundled version.
* Mon Mar 31 2014 pgajdos@suse.com
- update to 3.1.1:
  * FIX: Add asprint() compatibility function for systems lacking it
  * FIX: Fix ressource fork name conversion. Bug #534.
  * FIX: Fix a bug where only the first configured UAM was loaded.
    Bug #537.
  * UPD: Add support for AFP 3.4. From FR #85.
  * FIX: Registering with mDNS crashed. Bug #540
  * FIX: Saving from applications like Photoshop may fail, because
    removing the ressource fork AppleDouble file failed. Bug #542.
  * FIX: dbd: remove orphaned ._ AppleDouble files. Bug #549.
  * NEW: afpd: Automatic conversion of ._ AppleDouble files
    created by OS X. Bug #550.
  * FIX: afpd: Fix a crash in of_closefork(). Bug #551.
  * FIX: dbd: Don't print message "Ignoring ._file" for every ._ file.
    Bug #552.
  * FIX: afpd: Don't flood log with failed sys_set_ea() messages.
* Fri Nov 15 2013 pgajdos@suse.com
- update to 3.1.0:
    NEW: Add recvfile support with splice() on Linux. New global
    options "recvfile" (default: no) and "splice size"
    (default 64k).
    NEW: CNID backend "mysql" for use with a MySQL server
    FIX: Build fixes for the Kerberos UAM
    UPD: Use dedicated exit code for AFP connections that were
    dropped by the client right after the TCP handshake
    NEW: AFP Spotlight support with Gnome Tracker
    NEW: New option "spotlight" (G/V)
    NEW: If Spotlight is enabled, launch our own dbus instance
    NEW: New option "dbus daemon" (G)
    UPD: Add configure option --with-afpstats for overriding the
    result of autodetecting dbus-glib presence
- added wrong-error-message.patch [bnc#849598]
- added return-code.patch
* Wed Aug 28 2013 pgajdos@suse.com
- update to 3.0.5:
    FIX: Fix a crash when using pam_winbind. Fixes bug #516.
    NEW: New global/volume option "ignored attributes"
    FIX: "afp listen" option failed to take IPv6 addresses. Bug #515.
    FIX: Fix a possible crash in set_groups. Bug #518.
    NEW: Send optional AFP messages for vetoed files, new option "veto
    messages" can be used to enable sending messages. Then
    whenever a client tries to access any file or directory with
    a vetoed name, it will be sent an AFP message indicating the
    name and the directory. From FR #81.
    NEW: New boolean volume option "delete veto files". If this option
    is set to yes, then Netatalk will attempt to recursively
    delete any vetoed files and directories. FR #82.
    UPD: systemd unit dir is /usr/lib/systemd/system .
    FIX: Saving files from application like MS Word may result in the
    file loosing metadata like the Finder label. Bug #521.
* Sun Jun 16 2013 jengelh@inai.de
- Explicitly list libattr-devel as BuildRequires
- More robust make install call. Parallel build with %%_smp_mflags.
* Mon May 27 2013 pgajdos@suse.com
- update to 3.0.4:
    FIX: Opening files without metadata EA may result in an invalid
    metadata EA. Check for malformed metadata EAs and delete
    them. Fixes bug #510.
    FIX: Fix an issue with filenames containing non-ASCII characters
    that lead to a failure setting the size of a files ressource
    fork. This affected application like Adobe Photoshop where
    saving files may fail. Fixes bug #511.
    UPD: Enhance ACL mapping, change global ACL option map acl
    to take the following options: "none", "rights" (default),
    "mode". none = no mapping, this resembles the previous
    false/no setting rights = map ACLs to Finder UARights,
    this resembles the previous true/yes setting. This is the
    default. mode = map ACLs to Finder UARights and UNIX mode
    From FR #73.
    FIX: Fix a possible crash in cname() where cname_mtouname calls
    dirlookup() where the curdir is freed because the dircache
    detected a dev/inode cache difference and evicted the
    object from the cache. Fixes bug #498.
    FIX: Add missing include, fixes bug #512.
    FIX: Change default FinderInfo for directories to be all 0,
    fixes bug 514.
    NEW: New option "afp interfaces" which allows specifying where
    Netatalk listens for AFP connections by interface names.
    From FR #79.
* Mon May 13 2013 pgajdos@suse.com
- use --with-libevent=no, it means use system libevent (don't use
  bundled)
- remove rcnetatalk.sh, use upstream init script
* Mon May  6 2013 pgajdos@suse.com
- spec file cleanup according to upstream
* Tue Apr  2 2013 pgajdos@suse.com
- update to 3.0.3:
  * New ini style configuration file afp.conf which replaces all
    previous configuration files
  * New default AppleDouble backend using filesystem Extended
    Attributes, conversion from AppleDouble v2 is done automatically
    on access
  * New service controller process "netatalk" responsible for
    starting and restarting afpd and cnid_metad as necessary
  * AppleTalk support has been removed
  * Coherent cross-platform locking with Solaris CIFS server
- see http://netatalk.sourceforge.net/3.0/htmldocs/upgrade.html for
  upgrading instructions
* Tue Mar  5 2013 pgajdos@suse.com
- build with new automake
  * automake-1.13.patch
* Mon Feb 25 2013 mlin@suse.com
- Install netatalk.service accordingly (/usr/lib/systemd for 12.3
  and up or /lib/systemd for older versions).
  * Added netatalk-suse-servicedir-update.diff
* Tue Oct  2 2012 pgajdos@suse.com
- update to 2.2.4:
    FIX: Missing UAM links
    FIX: Lockup in AFP logout on Fedora 17
    FIX: Reset signal handlers and alarm timer after successfull PAM
    authentication. Fixes a problem with AFP disconnects caused
    by pam_smbpass.so messing with our handlers and timer.
    FIX: afpd: Fix a possible problem with sendfile on Solaris derived
    platforms
    NEW: afpd: support for mdnsresponder
    NEW: afpd: new LDAP config option ldap_uuid_string
    UPD: based on Unicode 6.1.0
    UPD: experimental systemd service files: always run both afpd
    and cnid_metad
    UPD: afpd: Ensure our umask is not altered by eg pam_umask
    UPD: afpd: Use GSS_C_NO_NAME as server principal when Kerberos
    options -fqdn and -krb5service are not set, from Jamie Gilbertson
    UPD: afpd: Changed behaviour for TimeMachine volumes in case there’s a
    problem talking to the CNID daemons. Previously the volume was
    flagged read-only and an AFP message was sent to the client.
    As this might result in TimeMachine assuming the backup sparse
    bundle is damaged, we now just switch the CNID database
    to an in-memory tdb without the additional stuff.
    FIX: afpd: sendfile() on FreeBSD was broken, courtesy of Denis Ahrens
    FIX: afpd: Dont use searchdb when doing partial name search
    FIX: afpd: Fix a possible bug handling disconnected sessions,
    NetAFP Bug ID #16
    FIX: afpd: Close IPC fds in afpd session child inherited from the afpd
    master process
    FIX: dbd: Don’t remove BerkeleyDB if it’s still in use by eg cnid_dbd,
    fixes bug introduced in 2.2.2
    FIX: debian initscript: start avahi-daemon (if available) before atalkd
    FIX: Zeroconf could not advertise non-ASCII time machine volume name
* Mon Feb  6 2012 pgajdos@suse.com
- update to 2.2.2:
  * AFP 3.3 support (necessary for TimeMachine and Lion)
  * Robust network disconnect/reconnect, especially important for Time Machine
  * Support for fast AFP searches (CNID backend "dbd" only)
  * POSIX draft 1e ACL support
  * Complete Netatalk volume compatible ad file utility suite
  * Dynamic filesystem cache
  * Builtin Zeroconf registration of the AFP server and TimeMachine volumes
  * Support for ACLs without a common Directory Service between server and client
  * Important: The enhancements for fast AFP searches are only implemented
    for the CNID backend "dbd" and require changes to the underlying CNID
    database, ie an additional index. This breaks drop-in compatibility
    between the CNID backends "cdb" and "dbd". Once "dbd" has upgraded
    a CNID database of a volume, "cdb" will reject to open it.
  * removed upstreamed build.patch
* Mon Jan 30 2012 pgajdos@suse.com
- require krb5-devel for build
* Thu Jan 12 2012 pgajdos@suse.com
- Shanti Kulkarni: compile netatalk with LDAP, ACL, Kerberos V,
  and quota options [bnc#740091]
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Sep  7 2011 pgajdos@suse.com
- updated to 2.2.1:
  * NEW: afpd: disable continous service feature by default, new option
  - keepsessions to enable it
  * NEW: configure option "--enable-redhat-systemd" for Fedora15 and later.
    "--enable-redhat" is renamed "--enable-redhat-sysv".
  * UPD: afpd: Enhance ACL support detection for volumes: enable them per
    volume if 1) ACL support compiled in, 2) the volume supports ACLs, 3)
    the new volume option "noacls" is not set for the volume. The previous
    behaviour was to enable ACL support for a volume if 1) it was compiled
    in and 2) the volume supported ACLs. There was no way to disable ACLs
    for a volume.
  * UPD: afpd: add a configurable hold time option to FCE file modification
    event generation, default is 60 s, new option "fceholdfmod" to change it
  * UPD: afpd: add support for new NetBSD quota subsystem, Bug ID 3249879
  * many bug fixes, see NEWS or
    http://netatalk.sourceforge.net/2.2/ReleaseNotes2.2.1.html
* Mon Aug 29 2011 pgajdos@suse.com
- don't use /var/lock/subsys in initscript [bnc#714662]
* Tue Aug 16 2011 stefan dot muenkner at mx dot uni-saarland dot de and pgajdos@novell.com
- updated to 2.2.0:
  * NEW: afpd: new volume option "nonetids"
  * NEW: afpd: ACL access check caching
  * NEW: afpd: FCE event notifications
  * NEW: afpd: new option "-mimicmodel" for specifying Bonjour model registration
  * UPD: Support for Berkeley DB 5.1
  * UPD: case-conversion is based on Unicode 6.0.0
  * UPD: cnid_metad: allow up to 4096 volumes
  * UPD: afpd: only forward SIGTERM and SIGUSR1 from parent to childs
  * UPD: afpd: use internal function instead of popening du -sh in order to
    calculate the used size of a volume for option "volsizelimit"
  * UPD: afpd: Add negative UUID caching, enhance local UUID handling
  * FIX: afpd: configuration reload with SIGHUP
  * FIX: afpd: crashes in the dircache
  * FIX: afpd: Correct afp logout vs dsi eof behaviour
  * FIX: afpd: new catsearch was broken
  * FIX: afpd: only use volume UUIDs in master afpd
  * FIX: dbd: Multiple fixes, reliable locking
  * FIX: ad file suite: fix an error that resulted in CNID database inconsistencies
* Thu May 26 2011 stefan dot muenkner at mx dot uni-saarland dot de and pgajdos@novell.com
- updated to 2.1.5:
  * removed upstreamed branch-netatalk-2-0.patch
  * removed upstreamed papd.vars.patch
  * removed unneeded papd.quote-vars.patch (pipexlate() function
    commented out in etc/papd/lp.c by upstream, see comment there)
  * removed unneeded papd.quote-vars.fixed.patch
  * removed upstreamed papd.stderr.patch
  * shortened 1.6-suse.patch
  * removed probably unneeded pie-flags.patch
  * removed probably unneeded la_libdir.patch
  * removed upstreamed ad_hf_mode.patch
  * removed upstreamed asingle-outofbounds.patch
* Thu Mar 26 2009 crrodriguez@suse.de
- remove static modules and "la" files
* Wed Jan 28 2009 olh@suse.de
- quote more chars in popen variables expansion (still bnc#463575)
* Fri Jan  9 2009 olh@suse.de
- remove unknown configure options --with-tcp-wrappers, --with-ssl
  and --with-mangling
- set cupsspool directory to /var/lib/cups/tmp, instead of
  non-existent /var/spool/netatalk
- add missing backslashes to our papd.conf example
- log cups provided temporary PPD files to syslog
- papd fixes from 2.0.4 (bnc#463575 - CVE-2008-5718):
  quote chars in popen variables expansion
  papd -d doesn't write to stderr. From Martin Nagy
  vars use %% not $
* Tue Sep 16 2008 lrupp@suse.de
- fix other rpmlint warnings/failures
* Wed Aug 27 2008 olh@suse.de
- add Should-Stop to rcatalk
  move dependencies from Required-Start to Should-Start
* Fri Mar 30 2007 olh@suse.de
- add zlib-devel to buildrequires
* Thu Mar 23 2006 olh@suse.de
- add AFPD_OPTIONS to netatalk.conf and start afpd with -t (160167)
* Tue Mar 21 2006 olh@suse.de
- store UTF8 per default on the server side
* Mon Mar 20 2006 olh@suse.de
- add upgrade_netatalk_AppleDB.sh to simplify upgrade of cnid.db
* Thu Mar 16 2006 olh@suse.de
- only run rcatalk as root (158466)
* Wed Feb 22 2006 olh@suse.de
- start slpd before atalk
- remove the 'mswindows' option from AppleVolumes.default,
  it appears now as volume name
- fix out-of-bounds access in asingle (151539)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Oct 21 2005 olh@suse.de
- update to current branch-netatalk-2-0 status
- link db4 with pthread
* Thu Sep 22 2005 olh@suse.de
- update to current branch-netatalk-2-0 status
  remove source dir from .la files
* Tue Jul 12 2005 olh@suse.de
- build with --disable-quota, librpcsvc.a is not compiled with -fPIC
  move -fpie/-pie flags from global CFLAGS to every subdir with
  binaries
* Tue Jun 21 2005 olh@suse.de
- update to netatalk 2.0.3
  build with -fpie/-pie
* Thu Mar 10 2005 olh@suse.de
- remove non-utf8 char from Applevolumes.default file (#71258)
  remove iso8859-1 encoding from AppleVolumes.default
* Sat Feb  5 2005 olh@suse.de
- update to current cvs netatalk-2.0 branch
* Tue Jan 25 2005 olh@suse.de
- Update to netatalk 2.0.2, enable openslp and cups
* Sat Nov 20 2004 schwab@suse.de
- Remove uniconv.
* Tue Nov 16 2004 schwab@suse.de
- Update to netatalk 2.0.1.
* Mon Nov 15 2004 kukuk@suse.de
- Use common-* PAM config files
* Thu Mar 18 2004 olh@suse.de
- add netatalk-1.6.4.etc2ps_tmpfile.patch,
  better tmpfile handling (#36371)
* Sat Jan 24 2004 olh@suse.de
- update to 1.6.5rc1
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Mon Sep  1 2003 olh@suse.de
- mark /usr/sbin/papd as root.lp in file list to match permissions
  (#29064)
* Sat Aug  9 2003 olh@suse.de
- update for struct quota renames, remove bogus casts
* Sat Jul  5 2003 olh@suse.de
- update to 1.6.3
* Sat May 10 2003 olh@suse.de
- handle Linux 2.5 struct renames
* Tue Apr 22 2003 olh@suse.de
- update to 1.6.2
* Wed Mar 19 2003 olh@suse.de
- update to 1.6.1
* Wed Feb 19 2003 olh@suse.de
- update to 1.6.1rc2, fixes for files without ressource fork:
  - It leaks a system file descriptor each time you open a data fork RW .
  - you can't open the missing ressource fork RW.
* Mon Feb 10 2003 olh@suse.de
- update to current branch-netatalk-1-6 branch
* Fri Feb  7 2003 kukuk@suse.de
- Use pam_unix2.so instead of pam_unix.so
- Change example password configuration from passwd.
* Tue Jan 28 2003 olh@suse.de
- do not install /usr/include/netatalk/at.h, conflicts with glibc
* Sun Jan 26 2003 olh@suse.de
- fix syslog output in etc/afpd/auth.c:login
  fix assignment in etc/afpd/filedir.c
  define _XOPEN_SOURCE in etc/uams/uams_pgp.c for crypt()
  update version number in README
  fix rcatalk path in /usr/bin/cnid_maint
  apply default settings to papd.conf and afpd.conf
  requiress db-utils for CNID DB
  do not use logfile feature
  provide example-configs in doc dir
  print hint in preinstall about changed path to config files
  correct path to netatalk.conf in rcatalk
* Tue Jan 21 2003 olh@suse.de
- update to 1.6.0
  enable CNID DB, enable filename mangling
  write logfile to /var/log/netatalk.log
* Wed Sep 18 2002 ro@suse.de
-  removed bogus self-provides
* Tue Sep 17 2002 olh@suse.de
- remove $netdaemons from required start
  not needed, disables inetd dependency
* Thu Aug 22 2002 olh@suse.de
- remove sgid from papd, not needed anymore with cups
* Tue Aug 20 2002 olh@suse.de
- add netatalk-1.5.3.1-papd_confoverflow.diff
  fixes buffer overflow in papd config file reading (#18103)
* Fri Aug  9 2002 olh@suse.de
- devel requires basepackage
* Wed Jul 31 2002 olh@suse.de
- add PreReq insserv_prereq  fillup_prereq
* Tue Jul 16 2002 olh@suse.de
- update to current 1.5.4 cvs, add libtatalk/pap to makerules
  rcnetatalk is now a separate file
* Fri May 24 2002 olh@suse.de
- add pap from current cvs
* Tue May 14 2002 olh@suse.de
- remove /usr/bin/acleandir.rc (what ever it is, it is evil)
* Fri May 10 2002 olh@suse.de
- add latinize.pl for easier migration to native Linux filenames
* Sat May  4 2002 olh@suse.de
- update to 1.5.3.1
* Mon Apr 29 2002 olh@suse.de
- move /etc/atalk/uams to /usr/lib/netatalk/
  use libdir for -devel pacakge
* Tue Mar 12 2002 draht@suse.de
- Don't run appletalk by default after installation.
* Fri Feb 15 2002 olh@suse.de
- make startup scripts LSB conform (#13288)
* Mon Feb 11 2002 olh@suse.de
- fix startup scripts for real
* Mon Feb 11 2002 olh@suse.de
- fix startup scripts
  print hint on atalkd startup failure
* Mon Feb 11 2002 olh@suse.de
- update to 1.5.1.1
* Tue Jan 15 2002 olh@suse.de
- update to 1.5.0
* Tue Jan 15 2002 egmont@suselinux.hu
- removed colons from startup/shutdown messages
* Fri Nov 23 2001 olh@suse.de
- update to current CVS, implement new startup scheme
* Sat Oct  6 2001 olh@suse.de
- provide a default printer in papd.conf
* Sat Oct  6 2001 olh@suse.de
- update to 1.5pre8 + CVS
* Tue Oct  2 2001 olh@suse.de
- start netatalk in background per default
* Fri Sep 28 2001 olh@suse.de
- really fix the startup script
  * libatalk/cnid/cnid_open.c: Set internal deadlock detection
* Sat Sep 22 2001 olh@suse.de
- fix startup scripts
  make nls codepage
* Sat Sep 22 2001 olh@suse.de
- fix codepage conversion (#10828)
* Fri Sep 21 2001 olh@suse.de
- update to current CVS, seems to fix netatalk MacOS X connects
* Sat Sep  1 2001 olh@suse.de
- fix initscript to not use "" in server name argument
* Sat Sep  1 2001 olh@suse.de
- update to current CVS
* Sat Sep  1 2001 olh@suse.de
- fix build, rm acinclude.m4
* Thu Aug 30 2001 olh@suse.de
- update to 1.5pre7, use db3/db.h
* Mon Aug 20 2001 olh@suse.de
- update to current CVS version
* Fri Jul 20 2001 olh@suse.de
- update to current CVS version
* Mon Jun 25 2001 olh@suse.de
- more info about remote quark ...
* Mon Jun 25 2001 olh@suse.de
- fix Makefile.am
* Sat Jun 23 2001 olh@suse.de
- update README.SuSE with some Quark stuff, update rc script
* Thu Jun 21 2001 olh@suse.de
- update to current CVS version, seems to work...
* Wed May  9 2001 olh@suse.de
- disable --enable-debug option, useless for production
  fills up the logfiles ...
* Thu Mar 29 2001 schwab@suse.de
- Use $(CC) instead of $(LD).
* Tue Jan 23 2001 olh@suse.de
- build with --enable-lastdid
* Wed Jan 17 2001 olh@suse.de
- fix filelist
* Wed Jan 17 2001 olh@suse.de
- move /lib/security/* to /etc/pam.d/*
* Thu Jan 11 2001 olh@suse.de
- use --with-flock-locks, seems to fix bugs when you edit files in
  Quark Express on the server volume
- add ATALK_AFPD_OPTIONS in rc.config to pass options to the afpd
* Mon Dec 11 2000 olh@suse.de
- --enable-debug, noreplace for config files (#4501)
* Tue Dec  5 2000 olh@suse.de
- disable suseupdateconfig for now
* Mon Dec  4 2000 ro@suse.de
- avoid conflict with glibc-devel
* Tue Nov 28 2000 ro@suse.de
- fixed Makefiles ... needs further testing
* Tue Nov 28 2000 ro@suse.de
- update to 1.4.99
- initscript to etc/init.d
* Wed May 24 2000 uli@suse.de
- moved docs to /usr/share
* Sat Apr 29 2000 kukuk@suse.de
- Add tcpd to need for build, fix quota prototypes
* Thu Mar  2 2000 olh@suse.de
- add some extensions, fix .pdf files
* Wed Mar  1 2000 werner@suse.de
- Fix config.guess selection
* Tue Jan 18 2000 cep@suse.de
- fit to new man path /usr/share/man
* Thu Dec  2 1999 olh@suse.de
- set papd g+s lp to correct the permissions of the spool files
* Tue Oct 26 1999 cep@suse.de
- enabled PAM support, tested against MacOS 8.5
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jun 15 1999 ro@suse.de
- create nls-dir before make install
* Thu Jun 10 1999 cep@suse.de
- updated to recent version netatalk-1.4b2+asun2.1.3, checked with
  Mac OS D1-8.5.1, Mac OS Rom D1 - 1.2
- added entry eth0 to /etc/atalk/atalkd.conf
* Tue Feb  2 1999 ro@suse.de
- use lcrypt on alpha as well
* Fri Jan  8 1999 cep@suse.de
- modified /sbin/init.d/atalk due to very long startup time of atalkd
* Fri Dec 11 1998 tmg@suse.de
- changed START_ATALK default to no
* Tue Dec  8 1998 ro@suse.de
- updated init-script and added rc-link
* Tue Oct  6 1998 ro@suse.de
- link with -lcrypt where necessary
- only include sys/types in at.h for glibc
* Sun Jul 26 1998 bs@suse.de
- install at.h as at.netatalk.h.
* Fri Jul 17 1998 reinhold@suse.de
- AFP 2.2 (Appleshare TCPIP) support included (asun2.0a18.2-0 patch)
* Sun Mar  1 1998 reinhold@suse.de
- README.SuSE updated
* Fri Feb 20 1998 reinhold@suse.de
- support for shadow included
* Wed Dec  3 1997 bs@suse.de
- install /usr/include/netatalk/at.h as at.netatalk.h (at.h ist also
  in libc)
* Tue Aug 19 1997 reinhold@suse.de
- war heiss heute
